@@ -24,16 +24,34 @@
 #ifndef _MANAGER_SENSOR_SERVER_H
 #define _MANAGER_SENSOR_SERVER_H
 
+#include "server-logic.h"
+#include "idmef-message-scheduler.h"
+#include "reverse-relaying.h"
+
+typedef struct {
+        SERVER_GENERIC_OBJECT;
+        prelude_list_t list;
+        
+        idmef_queue_t *queue;
+        prelude_connection_t *cnx;
+        prelude_bool_t we_connected;
+        prelude_list_t write_msg_list;
+        reverse_relay_receiver_t *rrr;
+        pthread_mutex_t mutex;
+        uint32_t instance_id;
+} sensor_fd_t;
+
+
 void sensor_server_stop(server_generic_t *server);
 
 server_generic_t *sensor_server_new(void);
 
 int sensor_server_broadcast_admin_command(uint64_t *analyzerid, prelude_msg_t *msg);
 
-int sensor_server_add_client(server_generic_t *server, prelude_connection_t *cnx);
+int sensor_server_add_client(server_generic_t *server, server_generic_client_t **client, prelude_connection_t *cnx);
 
 int sensor_server_write_client(server_generic_client_t *dst, prelude_msg_t *msg);
 
-int sensor_server_queue_write_client(server_generic_client_t *client, void *msg);
+void sensor_server_queue_write_client(server_generic_client_t *client, prelude_msg_t *msg);
 
 #endif /* _MANAGER_SENSOR_SERVER_H */
